# Contributing to this repository
We love contributions from everyone. By participating in this project, you agree to abide by the RiverSafe [Code Of Conduct](CODE_OF_CONDUCT.md).

We expect everyone (including maintainers) to follow the code of conduct anywhere in RiverSafe's project codebases, issue trackers, chatrooms, and mailing lists.

## Getting started
Before you begin:

- Eze Cli and it's sub-repos are powered by python and docker, make sure you have the latest version installed
- Have you read the [Code Of Conduct](CODE_OF_CONDUCT.md)?
- Check out the [existing issues](https://github.com/RiverSafeUK/eze-cli/issues) to see if any issues you're interested in have already been raised

## Committing to the Project

You can contribute to the Eze project in several ways. 

Our small, but mighty :muscle: team is maintaining this repo, to preserve our bandwidth, off topic conversations will be closed.

### :mega: Discussions
Discussions are where we have conversations.

If you'd like help troubleshooting a docs PR you're working on, have a great new idea, or want to share something amazing you've learned in our docs, please contact the core team directly, we'd love to chat to you.

### :beetle: Issues
[Issues](https://docs.github.com/en/github/managing-your-work-on-github/about-issues) are used to track tasks that contributors can help with. If an issue has a triage label, we haven't reviewed it yet and you shouldn't begin work on it.

If you've found something in the application or the repo that should be updated, search open issues to see if someone else has reported the same thing. If it's something new, open an issue. We'll use the issue to have a conversation about the problem you want to fix.

### :hammer_and_wrench: Pull requests
A [pull request](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/about-pull-requests) is a way to suggest changes in our repository.

When we merge those changes, they will be merged into develop and push live next semver-ed release. :earth_africa: To learn more about opening a pull request in this repo, see [Opening a pull request](#opening-a-pull-request) below.

### :question: Support
We are a small team working hard to keep up with the demands of a continuously changing product. Unfortunately, we just can't help with support questions unrelated to this repository. 

If you are experiencing a technical problem with unrelated to our documentation or project we won't be able to help you.

# Contribution

CONTRIBUTING.md was based off excellent resources 
- [thoughtbot CONTRIBUTING.md](https://github.com/thoughtbot/guides/blob/main/CONTRIBUTING.md)
- [github docs CONTRIBUTING.md](https://github.com/github/docs/blob/main/CONTRIBUTING.md)